"""
Various utilities
"""
import numpy as np

rng = np.random.default_rng()


def phasemod(phase, low=np.pi):
    """
    Modulo phase such that it falls within the
    interval $[-low, 2\pi - low)$.
    """
    return (phase + low) % (2*np.pi) - low

def sine_fitfunc(t, amp=1, freq=1, phase=0, off=0):
    """Simple sine wave for fitting purposes"""
    return amp*np.sin( 2*np.pi*freq*t + phase) + off

def sampled_time(sample_rate=1, start=0, end=1, offset=0):
    return offset + np.arange(start, end, 1/sample_rate)

def noisy_sine_sampling(time, init_params, noise_sigma=1, rng=rng):
    if init_params[2] is None:
        init_params[2] = phasemod(2*np.pi*rng.random())

    samples = sine_fitfunc(time, *init_params)
    noise = rng.normal(0, noise_sigma, size=len(samples))

    return samples, noise

